import * as React from 'react';
import { type ReactElement } from 'react';
import { type FormControlProps, type ComponentsOverrides } from '@mui/material';
import type { CommonInputProps } from '../CommonInputProps';
/**
 * To edit arrays of data embedded inside a record, <ArrayInput> creates a list of sub-forms.
 *
 *  @example
 *
 *      import { ArrayInput, SimpleFormIterator, DateInput, TextInput } from 'react-admin';
 *
 *      <ArrayInput source="backlinks">
 *          <SimpleFormIterator>
 *              <DateInput source="date" />
 *              <TextInput source="url" />
 *          </SimpleFormIterator>
 *      </ArrayInput>
 *
 * <ArrayInput> allows the edition of embedded arrays, like the backlinks field
 * in the following post record:
 *
 * {
 *   id: 123
 *   backlinks: [
 *         {
 *             date: '2012-08-10T00:00:00.000Z',
 *             url: 'http://example.com/foo/bar.html',
 *         },
 *         {
 *             date: '2012-08-14T00:00:00.000Z',
 *             url: 'https://blog.johndoe.com/2012/08/12/foobar.html',
 *         }
 *    ]
 * }
 *
 * <ArrayInput> expects a single child, which must be a *form iterator* component.
 * A form iterator is a component accepting a fields object as passed by
 * react-hook-form-arrays's useFieldArray() hook, and defining a layout for
 * an array of fields. For instance, the <SimpleFormIterator> component
 * displays an array of fields in an unordered list (<ul>), one sub-form by
 * list item (<li>). It also provides controls for adding and removing
 * a sub-record (a backlink in this example).
 *
 * @see {@link https://react-hook-form.com/docs/usefieldarray}
 */
export declare const ArrayInput: (inProps: ArrayInputProps) => React.JSX.Element;
export declare const getArrayInputError: (error: any) => any;
export interface ArrayInputProps extends Omit<CommonInputProps, 'disabled' | 'readOnly'>, Omit<FormControlProps, 'defaultValue' | 'disabled' | 'readOnly' | 'onBlur' | 'onChange'> {
    className?: string;
    children: ReactElement;
    isFetching?: boolean;
    isLoading?: boolean;
    isPending?: boolean;
}
export declare const ArrayInputClasses: {
    root: string;
    label: string;
};
declare module '@mui/material/styles' {
    interface ComponentNameToClassKey {
        RaArrayInput: 'root' | 'label';
    }
    interface ComponentsPropsList {
        RaArrayInput: Partial<ArrayInputProps>;
    }
    interface Components {
        RaArrayInput?: {
            defaultProps?: ComponentsPropsList['RaArrayInput'];
            styleOverrides?: ComponentsOverrides<Omit<Theme, 'components'>>['RaArrayInput'];
        };
    }
}
//# sourceMappingURL=ArrayInput.d.ts.map