import { ListProps } from '@mui/material';
import { type ComponentsOverrides } from '@mui/material/styles';
import { type RaRecord } from 'ra-core';
import * as React from 'react';
import { type ReactElement } from 'react';
import { type SimpleListBaseProps } from './SimpleListItem';
/**
 * The <SimpleList> component renders a list of records as a Material UI <List>.
 * It is usually used as a child of react-admin's <List> and <ReferenceManyField> components.
 *
 * Also widely used on Mobile.
 *
 * Props:
 * - primaryText: function returning a React element (or some text) based on the record
 * - secondaryText: same
 * - tertiaryText: same
 * - leftAvatar: function returning a React element based on the record
 * - leftIcon: same
 * - rightAvatar: same
 * - rightIcon: same
 * - linkType: deprecated - 'edit' or 'show', or a function returning 'edit' or 'show' based on the record
 * - rowClick: The action to trigger when the user clicks on a row.
 * - rowStyle: function returning a style object based on (record, index)
 * - rowSx: function returning a sx object based on (record, index)
 *
 * @example // Display all posts as a List
 * const postRowSx = (record, index) => ({
 *     backgroundColor: record.views >= 500 ? '#efe' : 'white',
 * });
 * export const PostList = () => (
 *     <List>
 *         <SimpleList
 *             primaryText={record => record.title}
 *             secondaryText={record => `${record.views} views`}
 *             tertiaryText={record =>
 *                 new Date(record.published_at).toLocaleDateString()
 *             }
 *             rowSx={postRowSx}
 *          />
 *     </List>
 * );
 */
export declare const SimpleList: <RecordType extends RaRecord<import("ra-core").Identifier> = any>(props: SimpleListProps<RecordType>) => React.JSX.Element | null;
export interface SimpleListProps<RecordType extends RaRecord = any> extends SimpleListBaseProps<RecordType>, Omit<ListProps, 'classes'> {
    className?: string;
    empty?: ReactElement;
    hasBulkActions?: boolean;
    resource?: string;
    data?: RecordType[];
    isLoading?: boolean;
    isPending?: boolean;
    isLoaded?: boolean;
    total?: number;
}
export declare const SimpleListClasses: {
    tertiary: string;
};
declare module '@mui/material/styles' {
    interface ComponentNameToClassKey {
        RaSimpleList: 'root' | 'tertiary';
    }
    interface ComponentsPropsList {
        RaSimpleList: Partial<SimpleListProps>;
    }
    interface Components {
        RaSimpleList?: {
            defaultProps?: ComponentsPropsList['RaSimpleList'];
            styleOverrides?: ComponentsOverrides<Omit<Theme, 'components'>>['RaSimpleList'];
        };
    }
}
//# sourceMappingURL=SimpleList.d.ts.map