import * as React from 'react';
import { type ComponentsOverrides, type SxProps, type Theme } from '@mui/material/styles';
import { type ExtractRecordPaths, type HintedString } from 'ra-core';
import type { FieldProps } from './types';
/**
 * Render a link to a file based on a path contained in a record field
 *
 * @example
 * import { FileField } from 'react-admin';
 *
 * <FileField source="url" title="title" />
 *
 * // renders the record { id: 123, url: 'doc.pdf', title: 'Presentation' } as
 * <div>
 *     <a href="doc.pdf" title="Presentation">Presentation</a>
 * </div>
 */
export declare const FileField: <RecordType extends Record<string, any> = Record<string, any>>(inProps: FileFieldProps<RecordType>) => React.JSX.Element;
export interface FileFieldProps<RecordType extends Record<string, any> = Record<string, any>> extends FieldProps<RecordType> {
    src?: string;
    title?: HintedString<ExtractRecordPaths<RecordType>>;
    target?: string;
    download?: boolean | string;
    ping?: string;
    rel?: string;
    sx?: SxProps<Theme>;
}
declare module '@mui/material/styles' {
    interface ComponentNameToClassKey {
        RaFileField: 'root';
    }
    interface ComponentsPropsList {
        RaFileField: Partial<FileFieldProps>;
    }
    interface Components {
        RaFileField?: {
            defaultProps?: ComponentsPropsList['RaFileField'];
            styleOverrides?: ComponentsOverrides<Omit<Theme, 'components'>>['RaFileField'];
        };
    }
}
//# sourceMappingURL=FileField.d.ts.map