var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import clsx from 'clsx';
import TextField from '@mui/material/TextField';
import { useInput, FieldTitle, useEvent } from 'ra-core';
import { sanitizeInputRestProps } from './sanitizeInputRestProps';
import { InputHelperText } from './InputHelperText';
import { useForkRef } from '@mui/material';
/**
 * Form input to edit a Date string value in the "YYYY-MM-DD" format (e.g. '2021-06-23').
 *
 * Renders a date picker (the exact UI depends on the browser).
 *
 * @example
 * import { Edit, SimpleForm, DateInput } from 'react-admin';
 *
 * const PostEdit = () => (
 *     <Edit>
 *         <SimpleForm>
 *             <DateInput source="published_at" />
 *         </SimpleForm>
 *     </Edit>
 * );
 *
 * @example
 * // If the initial value string contains more than a date (e.g. an hour, a timezone),
 * // these details are ignored.
 * <DateInput source="published_at" defaultValue="2021-09-11T20:46:20.000-04:00" />
 * // The input will display '2021-09-11' regardless of the browser timezone.
 *
 * @example
 * // If the initial value is a Date object, DateInput converts it to a string
 * // and ignores the timezone.
 * <DateInput source="published_at" defaultValue={new Date("2021-09-11T20:46:20.000-04:00")} />
 * // The input will display '2021-09-11' regardless of the browser timezone.
 *
 * @example
 * // If you want to manipulate the value from the field to adjust its timezone, use the format prop
 * <DateInput source="published_at" format={value => new Date(value).toISOString().split("T")[0} />
 * // The input will display the UTC day regardless of the browser timezone.
 *
 * @example
 * // If you want the returned value to be a Date, you must pass a custom parse method
 * to convert the form value (which is always a date string) back to a Date object.
 * <DateInput source="published_at" parse={val => new Date(val)} />
 */
export var DateInput = function (_a) {
    var className = _a.className, defaultValue = _a.defaultValue, _b = _a.format, format = _b === void 0 ? defaultFormat : _b, label = _a.label, source = _a.source, resource = _a.resource, helperText = _a.helperText, margin = _a.margin, onChange = _a.onChange, onFocus = _a.onFocus, validate = _a.validate, variant = _a.variant, disabled = _a.disabled, readOnly = _a.readOnly, rest = __rest(_a, ["className", "defaultValue", "format", "label", "source", "resource", "helperText", "margin", "onChange", "onFocus", "validate", "variant", "disabled", "readOnly"]);
    var _c = useInput(__assign({ defaultValue: defaultValue, resource: resource, source: source, validate: validate, disabled: disabled, readOnly: readOnly, format: format }, rest)), field = _c.field, fieldState = _c.fieldState, id = _c.id, isRequired = _c.isRequired;
    var localInputRef = React.useRef();
    // DateInput is not a really controlled input to ensure users can start entering a date, go to another input and come back to complete it.
    // This ref stores the value that is passed to the input defaultValue prop to solve this issue.
    var initialDefaultValueRef = React.useRef(field.value);
    // As the defaultValue prop won't trigger a remount of the HTML input, we will force it by changing the key.
    var _d = React.useState(1), inputKey = _d[0], setInputKey = _d[1];
    // This ref let us track that the last change of the form state value was made by the input itself
    var wasLastChangedByInput = React.useRef(false);
    // This effect ensures we stays in sync with the react-hook-form state when the value changes from outside the input
    // for instance by using react-hook-form reset or setValue methods.
    React.useEffect(function () {
        var _a, _b;
        // Ignore react-hook-form state changes if it came from the input itself
        if (wasLastChangedByInput.current) {
            // Resets the flag to ensure futures changes are handled
            wasLastChangedByInput.current = false;
            return;
        }
        var hasNewValueFromForm = ((_a = localInputRef.current) === null || _a === void 0 ? void 0 : _a.value) !== field.value &&
            !(((_b = localInputRef.current) === null || _b === void 0 ? void 0 : _b.value) === '' && field.value == null);
        if (hasNewValueFromForm) {
            // The value has changed from outside the input, we update the input value
            initialDefaultValueRef.current = field.value;
            // Trigger a remount of the HTML input
            setInputKey(function (r) { return r + 1; });
            // Resets the flag to ensure futures changes are handled
            wasLastChangedByInput.current = false;
        }
    }, [setInputKey, field.value]);
    var onBlurFromField = field.onBlur;
    var hasFocus = React.useRef(false);
    // Update the input text when the user types in the input.
    // Also, update the react-hook-form value if the input value is a valid date string.
    var handleChange = useEvent(function (event) {
        if (onChange) {
            onChange(event);
        }
        if (typeof event.target === 'undefined' ||
            typeof event.target.value === 'undefined') {
            return;
        }
        var target = event.target;
        var newValue = target.value;
        var isNewValueValid = newValue === '' ||
            (target.valueAsDate != null &&
                !isNaN(new Date(target.valueAsDate).getTime()));
        // Some browsers will return null for an invalid date
        // so we only change react-hook-form value if it's not null.
        // The input reset is handled in the onBlur event handler
        if (newValue !== '' && newValue != null && isNewValueValid) {
            field.onChange(newValue);
            // Track the fact that the next react-hook-form state change was triggered by the input itself
            wasLastChangedByInput.current = true;
        }
    });
    var handleFocus = useEvent(function (event) {
        if (onFocus) {
            onFocus(event);
        }
        hasFocus.current = true;
    });
    var handleBlur = useEvent(function () {
        hasFocus.current = false;
        if (!localInputRef.current) {
            return;
        }
        var newValue = localInputRef.current.value;
        // To ensure users can clear the input, we check its value on blur
        // and submit it to react-hook-form
        var isNewValueValid = newValue === '' ||
            (localInputRef.current.valueAsDate != null &&
                !isNaN(new Date(localInputRef.current.valueAsDate).getTime()));
        if (isNewValueValid && field.value !== newValue) {
            field.onChange(newValue !== null && newValue !== void 0 ? newValue : '');
        }
        if (onBlurFromField) {
            onBlurFromField();
        }
    });
    var error = fieldState.error, invalid = fieldState.invalid;
    var renderHelperText = helperText !== false || invalid;
    var ref = field.ref, name = field.name;
    var inputRef = useForkRef(ref, localInputRef);
    return (React.createElement(TextField, __assign({ id: id, name: name, inputRef: inputRef, defaultValue: format(initialDefaultValueRef.current), key: inputKey, type: "date", onChange: handleChange, onFocus: handleFocus, onBlur: handleBlur, className: clsx('ra-input', "ra-input-".concat(source), className), size: "small", variant: variant, margin: margin, error: invalid, disabled: disabled || readOnly, readOnly: readOnly, helperText: renderHelperText ? (React.createElement(InputHelperText, { error: error === null || error === void 0 ? void 0 : error.message, helperText: helperText })) : null, label: label !== '' && label !== false ? (React.createElement(FieldTitle, { label: label, source: source, resource: resource, isRequired: isRequired })) : null, InputLabelProps: defaultInputLabelProps }, sanitizeInputRestProps(rest))));
};
/**
 * Convert Date object to String, using the local timezone
 *
 * @param {Date} value value to convert
 * @returns {String} A standardized date (yyyy-MM-dd), to be passed to an <input type="date" />
 */
var convertDateToString = function (value) {
    if (!(value instanceof Date) || isNaN(value.getDate()))
        return '';
    var localDate = new Date(value.getTime());
    var pad = '00';
    var yyyy = localDate.getFullYear().toString();
    var MM = (localDate.getMonth() + 1).toString();
    var dd = localDate.getDate().toString();
    return "".concat(yyyy, "-").concat((pad + MM).slice(-2), "-").concat((pad + dd).slice(-2));
};
var dateRegex = /^\d{4}-\d{2}-\d{2}$/;
var defaultInputLabelProps = { shrink: true };
/**
 * Convert a form state value to a date string for the `<input type="date">` value.
 *
 * Form state values can be anything from:
 * - a string in the "YYYY-MM-DD" format
 * - A valid date string
 * - an ISO date string
 * - a Date object
 * - a Linux timestamp
 * - an empty string
 *
 * When it's not a bare date string (YYYY-MM-DD), the value is converted to
 * this format using the JS Date object.
 * THIS MAY CHANGE THE DATE VALUE depending on the browser locale.
 * For example, the string "09/11/2021" may be converted to "2021-09-10"
 * in Honolulu. This is expected behavior.
 * If this is not what you want, you should provide your own parse method.
 *
 * The output is always a string in the "YYYY-MM-DD" format.
 *
 * @example
 * defaultFormat('2021-09-11'); // '2021-09-11'
 * defaultFormat('09/11/2021'); // '2021-09-11' (may change depending on the browser locale)
 * defaultFormat('2021-09-11T20:46:20.000Z'); // '2021-09-11' (may change depending on the browser locale)
 * defaultFormat(new Date('2021-09-11T20:46:20.000Z')); // '2021-09-11' (may change depending on the browser locale)
 * defaultFormat(1631385980000); // '2021-09-11' (may change depending on the browser locale)
 * defaultFormat(''); // null
 */
var defaultFormat = function (value) {
    // null, undefined and empty string values should not go through dateFormatter
    // otherwise, it returns undefined and will make the input an uncontrolled one.
    if (value == null || value === '') {
        return null;
    }
    // Date objects should be converted to strings
    if (value instanceof Date) {
        return convertDateToString(value);
    }
    // Valid date strings (YYYY-MM-DD) should be considered as is
    if (typeof value === 'string') {
        if (dateRegex.test(value)) {
            return value;
        }
    }
    // other values (e.g., localized date strings, timestamps) need to be converted to Dates first
    return convertDateToString(new Date(value));
};
//# sourceMappingURL=DateInput.js.map