var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import clsx from 'clsx';
import TextField from '@mui/material/TextField';
import { useInput, FieldTitle } from 'ra-core';
import { sanitizeInputRestProps } from './sanitizeInputRestProps';
import { InputHelperText } from './InputHelperText';
import { useForkRef } from '@mui/material';
/**
 * Input component for entering a date and a time with timezone, using the browser locale
 */
export var DateTimeInput = function (_a) {
    var className = _a.className, defaultValue = _a.defaultValue, _b = _a.format, format = _b === void 0 ? formatDateTime : _b, label = _a.label, helperText = _a.helperText, margin = _a.margin, onBlur = _a.onBlur, onChange = _a.onChange, onFocus = _a.onFocus, source = _a.source, resource = _a.resource, validate = _a.validate, variant = _a.variant, disabled = _a.disabled, readOnly = _a.readOnly, rest = __rest(_a, ["className", "defaultValue", "format", "label", "helperText", "margin", "onBlur", "onChange", "onFocus", "source", "resource", "validate", "variant", "disabled", "readOnly"]);
    var _c = useInput(__assign({ defaultValue: defaultValue, onBlur: onBlur, resource: resource, source: source, validate: validate, disabled: disabled, readOnly: readOnly, format: format }, rest)), field = _c.field, fieldState = _c.fieldState, id = _c.id, isRequired = _c.isRequired;
    var localInputRef = React.useRef();
    // DateInput is not a really controlled input to ensure users can start entering a date, go to another input and come back to complete it.
    // This ref stores the value that is passed to the input defaultValue prop to solve this issue.
    var initialDefaultValueRef = React.useRef(field.value);
    // As the defaultValue prop won't trigger a remount of the HTML input, we will force it by changing the key.
    var _d = React.useState(1), inputKey = _d[0], setInputKey = _d[1];
    // This ref let us track that the last change of the form state value was made by the input itself
    var wasLastChangedByInput = React.useRef(false);
    // This effect ensures we stays in sync with the react-hook-form state when the value changes from outside the input
    // for instance by using react-hook-form reset or setValue methods.
    React.useEffect(function () {
        var _a, _b;
        // Ignore react-hook-form state changes if it came from the input itself
        if (wasLastChangedByInput.current) {
            // Resets the flag to ensure futures changes are handled
            wasLastChangedByInput.current = false;
            return;
        }
        var hasNewValueFromForm = ((_a = localInputRef.current) === null || _a === void 0 ? void 0 : _a.value) !== field.value &&
            !(((_b = localInputRef.current) === null || _b === void 0 ? void 0 : _b.value) === '' && field.value == null);
        if (hasNewValueFromForm) {
            // The value has changed from outside the input, we update the input value
            initialDefaultValueRef.current = field.value;
            // Trigger a remount of the HTML input
            setInputKey(function (r) { return r + 1; });
            // Resets the flag to ensure futures changes are handled
            wasLastChangedByInput.current = false;
        }
    }, [setInputKey, field.value]);
    var onBlurFromField = field.onBlur;
    var hasFocus = React.useRef(false);
    // update the input text when the user types in the input
    var handleChange = function (event) {
        if (onChange) {
            onChange(event);
        }
        if (typeof event.target === 'undefined' ||
            typeof event.target.value === 'undefined') {
            return;
        }
        var target = event.target;
        var newValue = target.value;
        var isNewValueValid = newValue === '' || !isNaN(new Date(target.value).getTime());
        // Some browsers will return null for an invalid date
        // so we only change react-hook-form value if it's not null.
        // The input reset is handled in the onBlur event handler
        if (newValue !== '' && newValue != null && isNewValueValid) {
            field.onChange(newValue);
            // Track the fact that the next react-hook-form state change was triggered by the input itself
            wasLastChangedByInput.current = true;
        }
    };
    var handleFocus = function (event) {
        if (onFocus) {
            onFocus(event);
        }
        hasFocus.current = true;
    };
    var handleBlur = function () {
        hasFocus.current = false;
        if (!localInputRef.current) {
            return;
        }
        var newValue = localInputRef.current.value;
        // To ensure users can clear the input, we check its value on blur
        // and submit it to react-hook-form
        var isNewValueValid = newValue === '' ||
            !isNaN(new Date(localInputRef.current.value).getTime());
        if (isNewValueValid && field.value !== newValue) {
            field.onChange(newValue !== null && newValue !== void 0 ? newValue : '');
        }
        if (onBlurFromField) {
            onBlurFromField();
        }
    };
    var error = fieldState.error, invalid = fieldState.invalid;
    var renderHelperText = helperText !== false || invalid;
    var ref = field.ref, name = field.name;
    var inputRef = useForkRef(ref, localInputRef);
    return (React.createElement(TextField, __assign({ id: id, inputRef: inputRef, name: name, defaultValue: format(initialDefaultValueRef.current), key: inputKey, type: "datetime-local", onChange: handleChange, onFocus: handleFocus, onBlur: handleBlur, className: clsx('ra-input', "ra-input-".concat(source), className), size: "small", variant: variant, margin: margin, error: invalid, disabled: disabled || readOnly, readOnly: readOnly, helperText: renderHelperText ? (React.createElement(InputHelperText, { error: error === null || error === void 0 ? void 0 : error.message, helperText: helperText })) : null, label: label !== '' && label !== false ? (React.createElement(FieldTitle, { label: label, source: source, resource: resource, isRequired: isRequired })) : null, InputLabelProps: defaultInputLabelProps }, sanitizeInputRestProps(rest))));
};
var leftPad = function (nb) {
    if (nb === void 0) { nb = 2; }
    return function (value) {
        return ('0'.repeat(nb) + value).slice(-nb);
    };
};
var leftPad4 = leftPad(4);
var leftPad2 = leftPad(2);
/**
 * @param {Date} value value to convert
 * @returns {String} A standardized datetime (yyyy-MM-ddThh:mm), to be passed to an <input type="datetime-local" />
 */
var convertDateToString = function (value) {
    if (!(value instanceof Date) || isNaN(value.getDate()))
        return '';
    var yyyy = leftPad4(value.getFullYear());
    var MM = leftPad2(value.getMonth() + 1);
    var dd = leftPad2(value.getDate());
    var hh = leftPad2(value.getHours());
    var mm = leftPad2(value.getMinutes());
    return "".concat(yyyy, "-").concat(MM, "-").concat(dd, "T").concat(hh, ":").concat(mm);
};
// yyyy-MM-ddThh:mm
var dateTimeRegex = /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}$/;
var defaultInputLabelProps = { shrink: true };
/**
 * Converts a date from the dataProvider, with timezone, to a date string
 * without timezone for use in an <input type="datetime-local" />.
 *
 * @param {Date | String} value date string or object
 */
var formatDateTime = function (value) {
    // null, undefined and empty string values should not go through convertDateToString
    // otherwise, it returns undefined and will make the input an uncontrolled one.
    if (value == null || value === '') {
        return '';
    }
    if (value instanceof Date) {
        return convertDateToString(value);
    }
    // valid dates should not be converted
    if (dateTimeRegex.test(value)) {
        return value;
    }
    return convertDateToString(new Date(value));
};
//# sourceMappingURL=DateTimeInput.js.map