import * as React from 'react';
import { ReactElement, ReactNode } from 'react';
import type { SxProps } from '@mui/material';
import { ListItemProps } from '@mui/material';
import { Identifier, RaRecord } from 'ra-core';
import { RowClickFunction } from '../types';
export declare const SimpleListItem: <RecordType extends RaRecord<Identifier> = any>(props: SimpleListItemProps<RecordType>) => React.JSX.Element | null;
export type FunctionToElement<RecordType extends RaRecord = any> = (record: RecordType, id: Identifier) => ReactNode;
export type FunctionLinkType = (record: RaRecord, id: Identifier) => string;
export interface SimpleListBaseProps<RecordType extends RaRecord = any> {
    leftAvatar?: FunctionToElement<RecordType>;
    leftIcon?: FunctionToElement<RecordType>;
    primaryText?: FunctionToElement<RecordType> | ReactElement | string;
    /**
     * @deprecated use rowClick instead
     */
    linkType?: string | FunctionLinkType | false;
    /**
     * The action to trigger when the user clicks on a row.
     *
     * @see https://marmelab.com/react-admin/Datagrid.html#rowclick
     * @example
     * import { List, Datagrid } from 'react-admin';
     *
     * export const PostList = () => (
     *     <List>
     *         <Datagrid rowClick="edit">
     *             ...
     *         </Datagrid>                    </ListItem>

     *     </List>
     * );
     */
    rowClick?: string | RowClickFunction | false;
    rightAvatar?: FunctionToElement<RecordType>;
    rightIcon?: FunctionToElement<RecordType>;
    secondaryText?: FunctionToElement<RecordType> | ReactElement | string;
    tertiaryText?: FunctionToElement<RecordType> | ReactElement | string;
    rowSx?: (record: RecordType, index: number) => SxProps;
    rowStyle?: (record: RecordType, index: number) => any;
}
export interface SimpleListItemProps<RecordType extends RaRecord = any> extends SimpleListBaseProps<RecordType>, Omit<ListItemProps, 'button' | 'component' | 'id'> {
    rowIndex: number;
}
//# sourceMappingURL=SimpleListItem.d.ts.map