var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { styled, useThemeProps, } from '@mui/material/styles';
import get from 'lodash/get';
import { FilterLiveForm, useListContext, useResourceContext } from 'ra-core';
import * as React from 'react';
import { useCallback, useContext, useEffect, } from 'react';
import { FilterContext } from '../FilterContext';
import { FilterFormInput } from './FilterFormInput';
export var FilterForm = function (inProps) {
    var props = useThemeProps({
        props: inProps,
        name: PREFIX,
    });
    var filtersProps = props.filters, rest = __rest(props, ["filters"]);
    var filters = useContext(FilterContext) || filtersProps;
    return (React.createElement(FilterLiveForm, __assign({ formComponent: StyledForm }, sanitizeRestProps(rest)),
        React.createElement(FilterFormBase, { filters: filters })));
};
export var FilterFormBase = function (props) {
    var filters = props.filters;
    var resource = useResourceContext(props);
    var _a = useListContext(), _b = _a.displayedFilters, displayedFilters = _b === void 0 ? {} : _b, filterValues = _a.filterValues, hideFilter = _a.hideFilter;
    useEffect(function () {
        if (!filters)
            return;
        filters.forEach(function (filter) {
            if (filter.props.alwaysOn && filter.props.defaultValue) {
                throw new Error('Cannot use alwaysOn and defaultValue on a filter input. Please set the filterDefaultValues props on the <List> element instead.');
            }
        });
    }, [filters]);
    var getShownFilters = function () {
        if (!filters)
            return [];
        var values = filterValues;
        return filters.filter(function (filterElement) {
            var filterValue = get(values, filterElement.props.source);
            return (filterElement.props.alwaysOn ||
                displayedFilters[filterElement.props.source] ||
                !isEmptyValue(filterValue));
        });
    };
    var handleHide = useCallback(function (event) { return hideFilter(event.currentTarget.dataset.key); }, [hideFilter]);
    return (React.createElement(React.Fragment, null,
        getShownFilters().map(function (filterElement) { return (React.createElement(FilterFormInput, { key: filterElement.key || filterElement.props.source, filterElement: filterElement, handleHide: handleHide, resource: resource, className: FilterFormClasses.filterFormInput })); }),
        React.createElement("div", { className: FilterFormClasses.clearFix })));
};
var sanitizeRestProps = function (_a) {
    var hasCreate = _a.hasCreate, resource = _a.resource, props = __rest(_a, ["hasCreate", "resource"]);
    return props;
};
var PREFIX = 'RaFilterForm';
export var FilterFormClasses = {
    clearFix: "".concat(PREFIX, "-clearFix"),
    filterFormInput: "".concat(PREFIX, "-filterFormInput"),
};
var StyledForm = styled('form', {
    name: PREFIX,
    overridesResolver: function (props, styles) { return styles.root; },
})(function (_a) {
    var _b;
    var theme = _a.theme;
    return (_b = {
            display: 'flex',
            flex: '0 1 auto'
        },
        _b[theme.breakpoints.down('sm')] = {
            width: '100%',
        },
        _b[theme.breakpoints.up('sm')] = {
            minHeight: theme.spacing(8),
        },
        _b[theme.breakpoints.up('md')] = {
            flex: '0 1 100%',
        },
        _b.flexWrap = 'wrap',
        _b.alignItems = 'flex-end',
        _b.pointerEvents = 'none',
        _b.padding = "0 0 ".concat(theme.spacing(0.5), " 0"),
        _b['& .MuiFormHelperText-root'] = { display: 'none' },
        _b["& .".concat(FilterFormClasses.clearFix)] = { clear: 'right' },
        _b["& .".concat(FilterFormClasses.filterFormInput, " .MuiFormControl-root")] = {
            marginTop: "".concat(theme.spacing(1)),
        },
        _b);
});
var isEmptyValue = function (filterValue) {
    if (filterValue === '' || filterValue == null)
        return true;
    // If one of the value leaf is not empty
    // the value is considered not empty
    if (typeof filterValue === 'object') {
        return Object.keys(filterValue).every(function (key) {
            return isEmptyValue(filterValue[key]);
        });
    }
    return false;
};
//# sourceMappingURL=FilterForm.js.map